import * as React from 'react'
import { message, Upload } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { UploadChangeParam, RcFile } from 'antd/lib/upload'
interface UploadProps {
    limit?: number
    accept?: string
    onChange?: (data: string | string[]) => void
}
const customeUpload: React.FC<UploadProps> = (props) => {
    const { limit } = props
    const [state, setState] = React.useState<{ fileList: any[] }>({
        fileList: [],
    })
    const handleChange = (info: UploadChangeParam) => {
        setState((preState) => ({
            ...preState,
            fileList: info.fileList,
        }))
        const currentValues = info.fileList.map((element) => {
            return element.response?.data
        })
        props.onChange?.(limit ? currentValues.slice(0, 1) : currentValues)
    }
    const onBeforeUpload = (file: RcFile, FileList: RcFile[]) => {
        const hasFile = state.fileList.find(
            (tempFile) =>
                tempFile.name === file.name && file.type === tempFile.type
        )
        if (hasFile) {
            message.error('您已上传这个文件')
            return Promise.reject()
        }
        return Promise.resolve()
    }
    return (
        <Upload
            action="/api/v1/upload"
            listType="picture-card"
            accept={props.accept ?? 'image/*'}
            onChange={handleChange}
            beforeUpload={onBeforeUpload}
            onPreview={(file) => {
                window.open(file.response.data)
            }}
        >
            <div>
                <PlusOutlined />
                <div style={{ marginTop: 8 }}>点击上传</div>
            </div>
        </Upload>
    )
}
export default customeUpload
