import * as React from 'react'
import { Layout, Menu, Avatar, Input, Dropdown, Space } from 'antd'
import Icon, {
    DesktopOutlined,
    FileSyncOutlined,
    SettingOutlined,
    DownOutlined,
    LoginOutlined,
    UserOutlined,
} from '@ant-design/icons'
import { Helmet } from 'react-helmet'
import {
    RouteComponentProps,
    Redirect,
    useHistory,
    Link,
    Switch,
    Route,
} from 'react-router-dom'
import './index.scss'
import { menuConfigs } from '../router'
const { Header, Sider, Content } = Layout
const { SubMenu } = Menu

const BasicLayout: React.FC<RouteComponentProps & { routes?: any[] }> = ({
    children,
    routes = [],
}) => {
    const history = useHistory()
    const currentPathName = history.location.pathname
    let pageTitle = ''
    menuConfigs.forEach((element) => {
        const currentRoute = element.childs.find(
            (route) => route.key === currentPathName
        )
        if (!!currentRoute) {
            pageTitle = currentRoute.title
        }
    })
    const [state, setState] = React.useState(() => {
        let defaultOpenKeys: string[] = [],
            defaultSelectedKeys = [currentPathName]
        menuConfigs.forEach((element) => {
            if (element.childs.find((route) => route.key === currentPathName)) {
                defaultOpenKeys.push(element.key)
            }
        })
        const token = localStorage.getItem('token')
        const userName = localStorage.getItem('userName')
        return {
            token,
            defaultSelectedKeys,
            defaultOpenKeys,
            userName,
            appName: '供应商平台',
        }
    })
    const handleLogOut = () => {
        window.localStorage.clear()
        location.href = '/'
    }
    const handleSwitchRouter = ({ key }: any) => {
        history.push(key)
    }

    return (
        <Layout className="layout">
            <Helmet>
                <title>{pageTitle}</title>
            </Helmet>
            <Sider
                collapsible
                className="layout-sider"
                onCollapse={(collapsed) => {
                    setState((preState) => ({
                        ...preState,
                        appName: collapsed ? '供' : '供应商平台',
                    }))
                }}
            >
                <div className="logo">
                    <h3
                        onClick={() => {
                            history.push('/')
                        }}
                    >
                        {state.appName}
                    </h3>
                </div>
                <Menu
                    onClick={handleSwitchRouter}
                    mode="inline"
                    defaultOpenKeys={state.defaultOpenKeys}
                    defaultSelectedKeys={state.defaultSelectedKeys}
                >
                    {menuConfigs.map((element) => {
                        return (
                            <SubMenu
                                icon={element.icon}
                                key={element.key}
                                title={element.title}
                            >
                                {element.childs.map((child) => {
                                    return (
                                        <Menu.Item key={child.key}>
                                            {child.title}
                                        </Menu.Item>
                                    )
                                })}
                            </SubMenu>
                        )
                    })}
                </Menu>
            </Sider>
            <Layout>
                <Header className="layout-header">
                    <Dropdown
                        overlay={() => {
                            return (
                                <Menu>
                                    <Menu.Item>
                                        <Link to="setup">
                                            <SettingOutlined /> 个人中心
                                        </Link>
                                    </Menu.Item>
                                    <Menu.Item>
                                        <a
                                            target="_blank"
                                            rel="noopener noreferrer"
                                            onClick={handleLogOut}
                                        >
                                            <LoginOutlined></LoginOutlined> 退出
                                        </a>
                                    </Menu.Item>
                                </Menu>
                            )
                        }}
                    >
                        <a
                            className="ant-dropdown-link"
                            onClick={(e) => e.preventDefault()}
                        >
                            <UserOutlined
                                style={{ fontSize: 16 }}
                            ></UserOutlined>
                            {localStorage.getItem('username')}
                            <DownOutlined></DownOutlined>
                        </a>
                    </Dropdown>
                </Header>
                <Content className="layout-content">
                    <Switch>
                        {routes.map((element) => {
                            return (
                                <Route
                                    key={element.path}
                                    path={element.path}
                                    component={element.component}
                                ></Route>
                            )
                        })}
                    </Switch>
                </Content>
            </Layout>
        </Layout>
    )
}
export default BasicLayout
