import * as React from 'react'
import {
    Table,
    Button,
    Row,
    Modal,
    Form,
    Input,
    message,
    InputNumber,
} from 'antd'
import { ColumnProps } from 'antd/lib/table'
import { useVideoChanel, chanleState, useAddChanle } from '../../services/video'
const colunms: ColumnProps<any>[] = [
    {
        title: '通道号',
        key: 'channel_no',
        dataIndex: 'channel_no',
    },
    {
        title: '通道名',
        key: 'name',
        dataIndex: 'name',
    },
    {
        title: '状态',
        key: 'state',
        dataIndex: 'state',
        render: (propIndex) => {
            return chanleState[propIndex as 0 | 1]
        },
    },
]
const chanle: React.FC = (props) => {
    const [form] = Form.useForm()
    const [state, setState] = React.useState({
        modalVisible: false,
    })
    const [chaneListState, requestChaneList] = useVideoChanel()
    const [addChanleState, requestAddChanle] = useAddChanle()
    const parmas = new URLSearchParams(location.search)
    const sn = parmas.get('sn')
    React.useEffect(() => {
        if (sn) {
            requestChaneList({ sn })
        }
    }, [sn])
    const handleTrunModalVisible = () => {
        setState((preState) => ({
            ...preState,
            modalVisible: !preState.modalVisible,
        }))
    }
    const onAdd = () => {
        if (sn) {
            form.validateFields().then((data: any) => {
                requestAddChanle({
                    sn: sn,
                    ...data,
                })
                    .then(() => {
                        message.success('添加通道成功')
                        requestChaneList({ sn })
                        handleTrunModalVisible()
                    })
                    .catch((error) => {
                        message.error(error.message)
                    })
            })
        }
    }
    const onSearch = (data: any) => {
        requestChaneList({
            ...chaneListState.deepProps,
            ...data,
            page: 1,
        })
    }
    return (
        <>
            <Row justify="end" gutter={[0, 30]}>
                <Button type="primary" onClick={handleTrunModalVisible}>
                    添加
                </Button>
            </Row>
            <Row gutter={[0, 30]}>
                <Form layout="inline" onFinish={onSearch}>
                    <Form.Item name="channel_no" label="通道号">
                        <Input placeholder="请输入通道号"></Input>
                    </Form.Item>
                    <Button htmlType="submit">搜索</Button>
                </Form>
            </Row>
            <Table
                loading={chaneListState.loading}
                rowKey={(record) => record.id}
                columns={colunms}
                dataSource={chaneListState.dataSource}
                pagination={{
                    hideOnSinglePage: true,
                    total: chaneListState.total,
                    showSizeChanger: false,
                    current: chaneListState.page,
                    onChange: (page) => {
                        requestChaneList({ sn: sn as string, page })
                    },
                }}
            ></Table>
            <Modal
                destroyOnClose
                title="添加通道"
                visible={state.modalVisible}
                onCancel={handleTrunModalVisible}
                okText="确认"
                cancelText="取消"
                onOk={onAdd}
                okButtonProps={{ loading: addChanleState.loading }}
            >
                <Form form={form}>
                    <Form.Item
                        name="channelCount"
                        required
                        label="通道数"
                        labelCol={{ span: 4 }}
                        rules={[
                            {
                                required: true,
                                message: '请设置通道数',
                            },
                        ]}
                    >
                        <InputNumber
                            style={{ width: '100%' }}
                            min={1}
                            max={64}
                            placeholder="请设置通道数(数字)"
                        ></InputNumber>
                    </Form.Item>
                </Form>
            </Modal>
        </>
    )
}
export default chanle
