import React, { Fragment } from 'react'
import {
    Table,
    Row,
    Col,
    Button,
    Modal,
    Form,
    Input,
    Select,
    message,
    Drawer,
    Typography,
    Badge,
    Descriptions,
} from 'antd'
import { FormItemProps } from 'antd/lib/form'
import { ColumnProps } from 'antd/lib/table'
import { useCanDeleteDeviceList } from '../../services/device'
import {
    useDisassembleList,
    usePostDisassemble,
    DisassembleStatus,
} from '../../services/declare'
const { Option } = Select
const { Search } = Input
const { Text } = Typography
const rowDatas = [
    {
        name: '设备名',
        dataKey: 'device_name',
    },
    {
        name: '设备编号',
        dataKey: 'sn',
        span: 2,
    },
    {
        name: '设备类型',
        dataKey: 'type_name',
    },
    {
        name: '统一编码',
        dataKey: 'social_code',
    },
    {
        name: '项目名',
        dataKey: 'project_name',
    },
    {
        name: '安检备案号',
        dataKey: 'safety_record_no',
    },

    {
        name: '申请时间',
        dataKey: 'apply_time',
    },
    {
        name: '申请状态',
        dataKey: 'statusText',
    },
    {
        name: '拆机原因',
        dataKey: 'reason',
    },
    {
        name: '审核时间',
        dataKey: 'approve_time',
    },
    {
        name: '审批理由',
        dataKey: 'feedback',
    },
]
/**
 * 设备拆机页面
 */
const disassemble: React.FC = () => {
    const [form] = Form.useForm()
    const [searchState, setSearchSetate] = React.useState({
        page: 1,
        filter: '',
    })
    const [warehousingListState, requsetWarehousingList] = useDisassembleList()
    const [canDeleteListState, requestCanDeleteList] = useCanDeleteDeviceList()
    const [postState, requestPost] = usePostDisassemble()
    const [state, setState] = React.useState({
        modalVisible: false,
    })
    const [drawerState, handleChangeDrawerState] = React.useState<{
        visible: boolean
        values: any
    }>({
        visible: false,
        values: {},
    })
    React.useEffect(() => {
        requsetWarehousingList(searchState)
    }, [searchState])
    const columns: ColumnProps<any>[] = [
        {
            title: '设备名',
            dataIndex: 'device_name',
            key: 'device_name',
            render: (dataValue, record) => {
                return (
                    <a
                        target="_blank"
                        onClick={() => {
                            handleChangeDrawerState((preState) => ({
                                ...preState,
                                visible: true,
                                values: record,
                            }))
                        }}
                        rel="noopener noreferrer"
                    >
                        {dataValue}
                    </a>
                )
            },
        },
        {
            title: '设备编号',
            dataIndex: 'sn',
            key: 'sn',
        },
        {
            title: '设备类型',
            dataIndex: 'type_name',
            key: 'type_name',
        },

        {
            title: '工程项目',
            dataIndex: 'project_name',
            key: 'project_name',
        },
        {
            title: '安监备案号',
            dataIndex: 'safety_record_no',
            key: 'safety_record_no',
        },
        {
            title: '申请时间',
            dataIndex: 'apply_time',
            key: 'apply_time',
        },
        {
            title: '审核状态',
            dataIndex: 'status',
            key: 'status',
            render: (dataValue, record) => {
                const isRefuse = dataValue === 2
                return (
                    <Fragment>
                        <Badge status={isRefuse ? 'error' : 'default'}></Badge>
                        <Text type={isRefuse ? 'danger' : 'secondary'}>
                            {record.statusText}
                        </Text>
                    </Fragment>
                )
            },
        },
    ]
    const handleTurnModalVisible = () => {
        setState((preState) => ({
            ...preState,
            modalVisible: !preState.modalVisible,
        }))
    }
    React.useEffect(() => {
        if (state.modalVisible) {
            requestCanDeleteList()
        }
    }, [state.modalVisible])
    const handlePostForm = () => {
        form.validateFields().then((data: any) => {
            requestPost(data)
                .then(() => {
                    requsetWarehousingList(searchState)
                    handleTurnModalVisible()
                    message.success('申报成功')
                })
                .catch((error) => {
                    message.error(error)
                })
        })
    }
    const formItmes: FormItemProps[] = [
        {
            name: 'id',
            label: '设备名',
            labelCol: { span: 4 },
            required: true,
            children: (
                <Select placeholder="请选择设备">
                    {canDeleteListState.dataSource.map((element) => {
                        return (
                            <Option key={element.id} value={element.id}>
                                {element.name}
                            </Option>
                        )
                    })}
                </Select>
            ),
        },
        {
            name: 'reason',
            label: '拆机原因',
            labelCol: { span: 4 },
            children: <Input placeholder="请输入拆机原因"></Input>,
        },
    ]
    return (
        <>
            <Row justify="end">
                <Col>
                    <Button type="primary" onClick={handleTurnModalVisible}>
                        申报
                    </Button>
                </Col>
            </Row>
            <Row gutter={[0, 30]}>
                <Col span={4}>
                    <Search
                        placeholder="请输入设备名"
                        onSearch={(value) => {
                            setSearchSetate((preState) => ({
                                ...preState,
                                page: 1,
                                filter: value,
                            }))
                        }}
                    ></Search>
                </Col>
            </Row>
            <Table
                bordered
                rowKey={(record) => record.id}
                loading={warehousingListState.loading}
                columns={columns}
                pagination={{
                    hideOnSinglePage: true,
                    total: warehousingListState.total,
                    current: warehousingListState.page,
                    onChange: (page) => {
                        setSearchSetate((preState) => ({
                            ...preState,
                            page: 1,
                        }))
                    },
                }}
                dataSource={warehousingListState.dataSource}
            ></Table>
            <Modal
                okText="确认"
                cancelText="取消"
                okButtonProps={{ loading: postState.loading }}
                visible={state.modalVisible}
                onCancel={handleTurnModalVisible}
                title="拆机申请"
                onOk={handlePostForm}
            >
                <Form form={form}>
                    {formItmes.map((element) => {
                        return (
                            <Form.Item
                                key={element.name as string}
                                {...element}
                            ></Form.Item>
                        )
                    })}
                </Form>
            </Modal>
            <Drawer
                width={600}
                visible={drawerState.visible}
                title="拆机详情"
                onClose={() => {
                    handleChangeDrawerState({ visible: false, values: {} })
                }}
            >
                <Descriptions bordered title={null} column={{ xxl: 1,xl:1 }}>
                    {rowDatas.map((element) => {
                        return (
                            <Descriptions.Item
                                label={element.name}
                                key={element.dataKey}
                            >
                                {drawerState.values[element.dataKey]}
                            </Descriptions.Item>
                        )
                    })}
                </Descriptions>
            </Drawer>
        </>
    )
}
export default disassemble
