import * as React from 'react'
import { Link } from 'react-router-dom'
import { Form, Card, Input, Button, Layout, message } from 'antd'
import { FormItemProps } from 'antd/lib/form'
import { useSendCode, useChangePassWord } from '../../services/users'
import './index.scss'
const PhonepPattern = /^1[3456789]\d{9}$/

const { Header, Content } = Layout
const forget: React.FC = (props) => {
    const [form] = Form.useForm()
    const { state: sendCodeState, request: requestSendCode } = useSendCode()
    const { state: changeState, request: requestChange } = useChangePassWord()
    const handleSubmit = () => {
        form.validateFields()
            .then((data: any) => {
                requestChange({
                    ...data,
                    vcode: Number(data.vcode),
                })
                    .then(() => {
                        message.success('密码修改成功,请返回登录')
                        form.resetFields()
                    })
                    .catch((error) => {
                        message.error(error.message)
                    })
            })
            .catch((error) => {})
    }
    const formItems: FormItemProps[] = [
        {
            name: 'phone',
            rules: [
                {
                    required: true,
                    message: '请输入手机号',
                },
                {
                    pattern: PhonepPattern,
                    message: '请输入正确的手机号',
                },
            ],
            children: <Input></Input>,
            label: '手机号',
            required: true,
        },
        {
            name: 'vcode',
            label: '手机验证码',

            children: (
                <Input
                className="forgetForm-vcode-wrapper"
                    suffix={
                        <Button
                            loading={sendCodeState.loading}
                            type="text"
                            onClick={() => {
                                form.validateFields(['phone']).then(
                                    (data: any) => {
                                        requestSendCode(data)
                                            .then(() => {
                                                message.success(
                                                    '验证码已发送，请注意查收'
                                                )
                                            })
                                            .catch((error) => {
                                                message.error(error.message)
                                            })
                                    }
                                )
                            }}
                        >
                            发送验证码
                        </Button>
                    }
                ></Input>
            ),
            required: true,
        },
        {
            name: 'passwd',
            label: '密码',

            rules: [
                {
                    required: true,
                    message: '请输入密码',
                },
                {
                    min: 6,
                    message: '密码最少为6位',
                },
                {
                    max: 12,
                    message: '密码最大为12位',
                },
            ],
            children: <Input></Input>,
            required: true,
        },
        {
            name: 'confirmPassword',
            label: '确认密码',
            dependencies: ['passwd'],
            rules: [
                {
                    required: true,
                    message: '请输入确认密码',
                },
                ({ getFieldValue }) => ({
                    validator(rule, value) {
                        if (!value || getFieldValue('passwd') === value) {
                            return Promise.resolve()
                        }
                        return Promise.reject('密码输入不一致')
                    },
                }),
            ],
            children: <Input></Input>,
            required: true,
        },
    ]
    return (
        <Layout className="forget-wrapper">
            <Header>
                <h1>供应商</h1>
                <h3>
                    <Link to="/">登录</Link>
                </h3>
            </Header>
            <Content className="forget-content">
                <Card title={<h3>忘记密码</h3>} className="forget-form-card">
                    <Form
                        labelCol={{ span: 6 }}
                        form={form}
                        onFinish={handleSubmit}
                    >
                        {formItems.map((formItem) => {
                            return (
                                <Form.Item
                                    required
                                    rules={[
                                        {
                                            required: true,
                                            message: `请输入${formItem.label}`,
                                        },
                                    ]}
                                    key={formItem.name as string}
                                    {...formItem}
                                ></Form.Item>
                            )
                        })}
                        <Button
                            loading={changeState.loading}
                            block
                            type="primary"
                            htmlType="submit"
                        >
                            确认
                        </Button>
                    </Form>
                </Card>
            </Content>
        </Layout>
    )
}
export default forget
