import * as React from 'react'
import { Form, Input, Button, Row, Col, message, Card } from 'antd'
import { Link, RouteComponentProps } from 'react-router-dom'
import { UserOutlined, LockOutlined, VerifiedOutlined } from '@ant-design/icons'
import { useUserLogin, useCaptchaId } from '../../services/users'
import './index.scss'
const layout = {
    labelCol: { span: 6 },
    wrapperCol: { span: 24 },
}

const login = ({ history }: RouteComponentProps) => {
    const [state, setState] = React.useState({
        timestamp: Date.now(),
    })
    const [loginState, requestLogin] = useUserLogin()
    const [captchState, requestCaptchaId] = useCaptchaId()
    React.useEffect(() => {
        requestCaptchaId()
    }, [state.timestamp])
    const [form] = Form.useForm()
    const handleSubmit = (values: any) => {
        if (loginState.loading) {
            return
        }
        requestLogin({ ...values, captcha: captchState.data.capture_id })
            .then(() => {
                localStorage.setItem('username', values.user)
                message.success('登录成功', 1, () => {
                    history.replace('/admin')
                })
            })
            .catch((error) => {
                setState((preState) => ({ ...preState, timestamp: Date.now() }))
                message.error(error.message)
            })
    }
    return (
        <div className="login-wrapper">
            <Card className="login-form-card" title={<h2>供应商管理平台</h2>}>
                <Form
                    {...layout}
                    form={form}
                    initialValues={{ remember: true }}
                    onFinish={handleSubmit}
                    scrollToFirstError
                >
                    <Form.Item
                        name="user"
                        colon={false}
                        rules={[
                            {
                                required: true,
                                message: '请输入用户名!',
                            },
                        ]}
                    >
                        <Input
                            size="large"
                            prefix={<UserOutlined />}
                            placeholder="用户名"
                        />
                    </Form.Item>
                    <Form.Item
                        name="password"
                        colon={false}
                        rules={[
                            {
                                required: true,
                                message: '请输入密码!',
                            },
                        ]}
                    >
                        <Input.Password
                            size="large"
                            prefix={<LockOutlined />}
                            placeholder="密码"
                        />
                    </Form.Item>
                    <Form.Item
                        name="verify"
                        colon={false}
                        rules={[
                            {
                                required: true,
                                message: '请输入验证码!',
                            },
                        ]}
                    >
                        <Input
                            size="large"
                            className="login-form-code"
                            autoComplete="off"
                            suffix={
                                <img
                                    onClick={() => {
                                        setState((preState) => ({
                                            ...preState,
                                            timestamp: Date.now(),
                                        }))
                                    }}
                                    className="capture_img"
                                    src={`/api/v1/user/captcha_png/${captchState.data.capture_id}`}
                                ></img>
                            }
                            prefix={<VerifiedOutlined />}
                            placeholder="验证码"
                        />
                    </Form.Item>
                    <Form.Item wrapperCol={{ span: 24 }}>
                        <Button
                            size="large"
                            loading={loginState.loading}
                            type="primary"
                            htmlType="submit"
                            block
                        >
                            登录
                        </Button>
                    </Form.Item>
                    <Form.Item wrapperCol={{ span: 24 }}>
                        <Button
                            size="large"
                            block
                            onClick={() => {
                                history.push('/queryUser')
                            }}
                        >
                            查询
                        </Button>
                    </Form.Item>
                </Form>
                <Row justify="space-between">
                    <Link to="/register">供应商备案</Link>
                    <a href="/publicity.html">供应商公示</a>
                    <Link to="/forget">忘记密码?</Link>
                </Row>
            </Card>
        </div>
    )
}
export default login
