import * as React from 'react'
import {
    Layout,
    Tabs,
    Typography,
    Button,
    Radio,
    Space,
    Input,
    Result,
    Spin,
} from 'antd'
import './index.scss'
const { Content } = Layout
const { Title, Paragraph, Text } = Typography
import { useDeviceTotalTypes } from '../../services/DeviceTypes'
import request from '../../utils/request'
const { Search } = Input
/**
 * @description 供应商公示页面
 */
export default () => {
    const [state, setState] = React.useState({
        device_code: '',
        provider: '',
    })
    const [typesState, requestTypes] = useDeviceTotalTypes()
    React.useEffect(() => {
        requestTypes()
    }, [])
    const [resultState, setResultState] = React.useState<{
        results: { name: string; social_code: string }[]
        loading: boolean
        error: string
    }>({
        results: [],
        loading: false,
        error: '',
    })
    const handleRequestProvider = () => {
        setResultState((preState) => ({
            ...preState,
            loading: true,
            error: '',
        }))
        request
            .sendRequest({
                url: '/v1/publicity',
                params: state,
            })
            .then((data: any) => {
                setResultState((preState) => ({
                    ...preState,
                    results: data.list,
                    loading: false,
                }))
            })
            .catch((error) => {
                setResultState((preState) => ({
                    ...preState,
                    error: error.message,
                    loading: false,
                }))
            })
    }
    React.useEffect(() => {
        handleRequestProvider()
    }, [state.provider, state.device_code])
    return (
        <div className="publicity-layout">
            <Typography>
                <Title>成都市智慧工地供应商公示</Title>
                <Paragraph>
                    <ol>
                        <li>
                            以下供应商及设备对接测试已通过，现予以公开，有关单位可自主选择以下供应商设备，排名不分先后，用户访问时随机显示。
                        </li>
                        <li>
                            任何部门不得指定或限定供应商，干涉建设、施工单位自主选择权
                        </li>
                        <li>
                            建设、施工单位单位选用智慧工地相关设备时，要认真核对设备参数是否符合市住建局智慧工地设备相关要求。
                        </li>
                    </ol>
                </Paragraph>
            </Typography>
            <div className="publicity-search">
                <Radio.Group
                    onChange={(event) => {
                        setState((preState) => ({
                            ...preState,
                            device_code: event.target.value,
                        }))
                    }}
                    options={typesState.dataSource.map((element) => {
                        return {
                            label: element.type_name,
                            value: element.type_code,
                        }
                    })}
                    optionType="button"
                    buttonStyle="solid"
                />
                <Search
                    className="search-input"
                    onSearch={(value) => {
                        setState((preState) => ({
                            ...preState,
                            provider: value,
                        }))
                    }}
                    placeholder="请输入公司名称"
                ></Search>
            </div>

            <Content className="publicity-content">
                <Spin spinning={resultState.loading}>
                    {resultState.error ? (
                        <Result
                            status="error"
                            title="错误"
                            subTitle={resultState.error}
                            extra={
                                <Button
                                    type="primary"
                                    onClick={handleRequestProvider}
                                >
                                    重试
                                </Button>
                            }
                        ></Result>
                    ) : (
                        <Space>
                            {resultState.results.map((element) => {
                                return (
                                    <Button key={element.social_code}>
                                        {element.name}
                                    </Button>
                                )
                            })}
                        </Space>
                    )}
                </Spin>
            </Content>
        </div>
    )
}
