import React, { useMemo } from 'react'
import { RouteComponentProps } from 'react-router-dom'
import {
    SmileOutlined,
    LoadingOutlined,
    WarningOutlined,
} from '@ant-design/icons'
import {
    Layout,
    Typography,
    Input,
    Row,
    Col,
    Form,
    Button,
    Result,
    notification,
} from 'antd'
import { useQueryUser } from '../../services/users'

import './index.scss'
const { Title } = Typography
const regiseterResult: React.FC<RouteComponentProps> = ({ history }) => {
    const [form] = Form.useForm()
    const { state: queryState, request: requestQuery } = useQueryUser()
    const handleSubmit = (data: any) => {
        requestQuery(data).catch((error) => {
            notification.error({
                message: error.code,
                description: error.message,
            })
        })
    }
    const resultInfos = useMemo(() => {
        if (queryState.data) {
            let icon: React.ReactNode = <LoadingOutlined />,
                status: string = '',
                title: string = '正在等待审批中'
            const success = queryState.data.status === 1
            if (success) {
                icon = <SmileOutlined />
                status = 'success'
                title = '审核通过，注册成功'
            }
            const wait = queryState.data.status === 2
            if (wait) {
                icon = <WarningOutlined />
                status = 'error'
                title = '审核拒绝，注册失败'
            }
            return {
                icon,
                status,
                title,
            }
        }
    }, [queryState.data])
    return (
        <Layout className="regisetr-layout">
            <Layout.Header>
                <Title>供应商注册进度查询</Title>
            </Layout.Header>
            <Layout.Content>
                <Row justify="center">
                    <Col span={8}>
                        <Form onFinish={handleSubmit} form={form}>
                            <Form.Item
                                label="统一社会信用代码"
                                required
                                name="social_code"
                                rules={[
                                    {
                                        required: true,
                                        message: '请输入统一社会信用代码',
                                    },
                                ]}
                                children={<Input></Input>}
                            ></Form.Item>
                            <Button
                                type="primary"
                                block
                                htmlType="submit"
                                loading={queryState.loading}
                            >
                                查询
                            </Button>
                        </Form>
                    </Col>
                </Row>
                <Row justify="center">
                    <Col span={8}>
                        {queryState.data && (
                            <Result
                                icon={resultInfos?.icon}
                                status={resultInfos?.status as any}
                                title={resultInfos?.title}
                                subTitle={queryState.data.feedback}
                                extra={[
                                    <Button
                                        key="buy"
                                        onClick={() => {
                                            form.resetFields()
                                        }}
                                    >
                                        继续查询
                                    </Button>,
                                    <Button
                                        type="primary"
                                        key="console"
                                        onClick={() => {
                                            history.goBack()
                                        }}
                                    >
                                        返回
                                    </Button>,
                                ]}
                            />
                        )}
                    </Col>
                </Row>
            </Layout.Content>
        </Layout>
    )
}
export default regiseterResult
