import * as React from 'react'
import {
    Form,
    Row,
    Col,
    Spin,
    Divider,
    Input,
    Select,
    Button,
    Space,
    message,
    Result,
} from 'antd'
import { FormItemProps } from 'antd/lib/form'
import appointmentFile from '../../assets/appointment.rar'
import authorization from '../../assets/authorization.doc'
import committed from '../../assets/committed.doc'
import Upload from '../../components/upload'
import Request from '../../utils/request'
import './index.scss'
const PhonepPattern = /^1[3456789]\d{9}$/
const { Search } = Input

const register: React.FC = () => {
    const [form] = Form.useForm()
    const [state, setState] = React.useState({
        loadingSend: false,
        loading: false,
        success: false,
    })
    const [formValue, handleChanfeFormValue] = React.useState<{
        enterprise_location: 0 | 1
    }>({
        enterprise_location: 0,
    })
    React.useEffect(() => {
        form.validateFields(['business_responsible_letter'])
    }, [formValue.enterprise_location])
    const handleSubmit = (data: any) => {
        setState((preState) => ({ ...preState, loading: true }))
        Request.sendRequest({
            url: '/v1/user/register',
            method: 'POST',
            data,
        })
            .then(() => {
                setState((preState) => ({
                    ...preState,
                    loading: false,
                    success: true,
                }))
            })
            .catch((error) => {
                message.error(error.message)
                setState((preState) => ({ ...preState, loading: false }))
            })
    }
    const handlsSendCode = (phone: string) => {
        form.validateFields(['business_contact_phone']).then(
            ({ business_contact_phone }) => {
                setState((preState) => ({ ...preState, loadingSend: true }))
                Request.sendRequest({
                    url: '/v1/vcode',
                    params: {
                        phone: business_contact_phone,
                    },
                })
                    .then(() => {
                        message.success('验证码发送成功')
                    })
                    .catch((error) => {
                        message.error(error.message)
                    })
                    .finally(() => {
                        setState((preState) => ({
                            ...preState,
                            loadingSend: false,
                        }))
                    })
            }
        )
    }
    const formInputs: FormItemProps[] = [
        {
            label: '供应商名称',
            name: 'name',
            required: true,
            children: <Input placeholder="请输入供应商名称"></Input>,
        },
        {
            label: '统一社会信用代码',
            name: 'social_code',
            required: true,

            children: <Input placeholder="请输入统一社会信用代码"></Input>,
        },
        {
            label: '法定代表人',
            name: 'legal_person',

            children: <Input placeholder="请输入法定代表人"></Input>,
        },
        {
            label: '身份证号',
            name: 'id_cert',

            children: <Input placeholder="请输入身份证号"></Input>,
        },
        {
            label: '企业所属',
            name: 'enterprise_location',
            initialValue: 0,
            extra: formValue.enterprise_location
                ? '省外企业须上传业务负责人任命书'
                : '',
            rules: [
                {
                    required: true,
                },
            ],
            children: (
                <Select
                    placeholder="请选择企业所属"
                    onChange={(value) => {
                        handleChanfeFormValue((preState) => ({
                            ...preState,
                            enterprise_location: value as 0 | 1,
                        }))
                    }}
                >
                    <Select.Option value={0}>省内</Select.Option>
                    <Select.Option value={1}>省外</Select.Option>
                </Select>
            ),
        },

        {
            label: '营业执照扫描件',
            name: 'business_license',
            children: <Upload></Upload>,
            extra: '上传正副本皆可，支持pdf,jpg,jpeg,png等格式',
            rules: [
                {
                    required: true,
                    message: '请上传营业执照扫描件',
                },

            ],
        },
        {
            label: '诚信经营承诺书',
            extra: (
                <div>
                    支持pdf,jpg,jpeg,png等格式。
                    <a href={committed} download="诚信经营承诺书.doc">
                        下载模板
                    </a>
                </div>
            ),
            rules: [
                {
                    required: true,
                    message: '请上传诚信经营承诺书',
                },
            ],
            name: 'integrity_management_letter',
            children: <Upload></Upload>,
        },
        {
            label: '法人授权书',
            extra: (
                <div>
                    支持pdf,jpg,jpeg,png等格式。
                    <a href={authorization} download="法人授权书.rar">
                        下载模板
                    </a>
                </div>
            ),
            name: 'legal_person_letter',
            children: <Upload></Upload>,
            rules: [
                {
                    required: true,
                    message: '请上传法人授权书',
                },
            ],
        },
        {
            label: '业务负责人任命书',
            required: !!formValue.enterprise_location,
            initialValue:[],
            extra: (
                <div>
                    支持pdf,jpg,jpeg,png等格式。
                    <a href={appointmentFile} download="业务负责人任命书.rar">
                        下载模板
                    </a>
                </div>
            ),
            rules: [
                {
                    required: !!formValue.enterprise_location,
                    message: '请上传业务负责人任命书',
                },
            ],
            name: 'business_responsible_letter',
            children: <Upload></Upload>,
        },

        {
            label: '用户名',
            name: 'user_name',

            children: <Input placeholder="请输入用户名"></Input>,
        },
        {
            label: '密码',
            name: 'passwd',

            children: (
                <Input.Password placeholder="请输入密码"></Input.Password>
            ),
        },
        {
            label: '确认密码',

            dependencies: ['passwd'],
            name: 'confirmpasswd',
            rules: [
                {
                    required: true,
                    message: '请输入确认密码',
                },
                ({ getFieldValue }) => ({
                    validator(rule, value) {
                        if (!value || getFieldValue('passwd') === value) {
                            return Promise.resolve()
                        }
                        return Promise.reject('密码输入不一致')
                    },
                }),
            ],
            children: (
                <Input.Password placeholder="请确认密码"></Input.Password>
            ),
        },
        {
            label: '业务联系人',

            name: 'business_contact',
            children: <Input placeholder="请输入业务联系人"></Input>,
        },
        {
            label: '业务联系人电话',

            name: 'business_contact_phone',
            rules: [
                {
                    whitespace: true,
                },
                {
                    required: true,
                    message: '请输入业务联系人电话',
                },
                {
                    pattern: PhonepPattern,
                    message: '请输入正确的手机号',
                },
            ],
            children: <Input placeholder="请输入业务联系人电话"></Input>,
        },
        {
            label: '业务负责人',
            name: 'business_responsible',

            children: <Input placeholder="请输入业务负责人"></Input>,
        },
        {
            label: '业务负责人电话',

            name: 'business_responsible_phone',
            help: '业务联系人电话接收验证码',
            rules: [
                {
                    whitespace: true,
                },
                {
                    required: true,
                    message: '请输入业务负责人电话',
                },
                {
                    pattern: PhonepPattern,
                    message: '请输入正确的手机号',
                },
            ],
            children: <Input placeholder="请输入业务负责人电话"></Input>,
        },
        {
            label: '应急联系人',
            name: 'emergency_contact',

            children: <Input placeholder="请输入应急联系人"></Input>,
        },
        {
            label: '应急联系人电话',

            name: 'emergency_contact_phone',
            rules: [
                {
                    whitespace: true,
                },
                {
                    required: true,
                    message: '请输入应急联系人电话',
                },
                {
                    pattern: PhonepPattern,
                    message: '请输入正确的手机号',
                },
            ],
            children: <Input placeholder="请输入应急联系人电话"></Input>,
        },
        {
            label: '验证码',
            name: 'verify',
            children: (
                <Search
                    onSearch={handlsSendCode}
                    loading={state.loadingSend}
                    placeholder="请输入业务联系人得接收验证码"
                    enterButton="发送验证码"
                ></Search>
            ),
        },
    ]
    if (state.success) {
        return (
            <Result
                status="success"
                title="恭喜您提交资料成功"
                extra={[
                    <Button
                        type="primary"
                        key="console"
                        onClick={() => {
                            history.back()
                        }}
                    >
                        返回
                    </Button>,
                    <Button
                        key="buy"
                        onClick={() => {
                            setState((preState) => ({
                                ...preState,
                                success: false,
                            }))
                        }}
                    >
                        继续
                    </Button>,
                ]}
            />
        )
    }
    return (
        <div className="register-layout">
            <div className="register-header">
                <h1>成都市智慧工地供应商服务系统</h1>
            </div>
            <Divider>
                <h2>供应商注册</h2>
            </Divider>
            <Spin spinning={state.loading}>
                <Form
                    form={form}
                    onFinish={handleSubmit}
                    className="register-form"
                    labelCol={{ span: 6 }}
                    wrapperCol={{ span: 12 }}
                >
                    <Row justify="center">
                        {formInputs.map((element) => {
                            return (
                                <Col key={element.name as string} span={13}>
                                    <Form.Item
                                        hasFeedback
                                        rules={[
                                            {
                                                required: true,
                                                message: `请输入${element.label}`,
                                            },
                                            {
                                                whitespace: true,
                                            },
                                        ]}
                                        required
                                        colon
                                        {...element}
                                    ></Form.Item>
                                </Col>
                            )
                        })}
                    </Row>
                    <Row justify="center">
                        <Col span={6}>
                            <Space>
                                <Button
                                    type="primary"
                                    size="large"
                                    htmlType="submit"
                                >
                                    提交
                                </Button>
                                <Button
                                    size="large"
                                    htmlType="reset"
                                    onClick={() => (window.location.href = '/')}
                                >
                                    返回
                                </Button>
                            </Space>
                        </Col>
                    </Row>
                </Form>
            </Spin>
        </div>
    )
}
export default register
