import * as React from 'react'
import {
    Table,
    Row,
    Col,
    Button,
    Modal,
    Input,
    Form,
    Select,
    message,
    Typography,
    Badge,
} from 'antd'
import { EyeOutlined, EyeInvisibleOutlined } from '@ant-design/icons'
import { ColumnProps } from 'antd/lib/table'
import { RouteComponentProps } from 'react-router-dom'
import {
    useVideoList,
    VideoStatus,
    VideoState,
    useAddVideo,
} from '../../services/video'
import { useProjectList } from '../../services/project'
const { Search } = Input
const { Text } = Typography
const videos: React.FC<RouteComponentProps> = ({ history }) => {
    const [searchState, setSearchState] = React.useState({
        page: 1,
        filter: '',
    })
    React.useEffect(() => {
        requestVideoList(searchState)
    }, [searchState])
    const [form] = Form.useForm()
    const [VideoListState, requestVideoList] = useVideoList()
    const [projectListState, requestProjectList] = useProjectList()
    const [addState, requestAdd] = useAddVideo()
    const [state, setState] = React.useState<{
        visibleModal: boolean
    }>({
        visibleModal: false,
    })

    const videoListColums: ColumnProps<any>[] = [
        {
            title: '项目名',
            dataIndex: 'project_name',
            key: 'project_name',
        },
        {
            title: '设备名',
            dataIndex: 'name',
            key: 'name',
        },
        {
            title: '国标编号',
            dataIndex: 'sn',
            key: 'sn',
        },
        {
            title: '传输模式',
            dataIndex: 'media_transport',
            key: 'media_transport',
        },
        {
            title: '通道数',
            dataIndex: 'channel_count',
            key: 'channel_count',
        },
        {
            title: 'IP',
            dataIndex: 'ip',
            key: 'ip',
        },
        {
            title: '端口',
            dataIndex: 'port',
            key: 'port',
        },

        {
            title: '确认状态',
            dataIndex: 'status',
            key: 'status',
            render: (dataIndex: 0 | 1 | 2) => VideoStatus[dataIndex],
        },
        {
            title: '状态',
            dataIndex: 'state',
            key: 'state',
            render: (dataIndex: 0 | 1, record) => {
                const online = dataIndex === 1;
                return record.status === 1 ? (
                    <>
                        <Badge status={online ? 'success' : 'error'}></Badge>
                        <Text type={dataIndex === 1 ? 'success' : 'secondary'}>
                            {VideoState[dataIndex as 0 | 1]}
                        </Text>
                    </>
                ) : null
            },
        },
        {
            title: '操作',
            render: (record: any) =>
                record.status === 1 ? (
                    <Button
                        icon={<EyeOutlined></EyeOutlined>}
                        type="primary"
                        onClick={() => {
                            history.push(
                                `/admin/equipment/chanle?sn=${record.sn}`
                            )
                        }}
                    >
                        查看通道
                    </Button>
                ) : null,
        },
    ]

    const handleTurnChanleModal = () => {
        setState((preState) => ({
            ...preState,
            visibleModal: !preState.visibleModal,
        }))
    }
    const onAdd = () => {
        form.validateFields().then((data: any) => {
            requestAdd(data)
                .then(() => {
                    message.success('添加视频监控成功')
                    handleTurnChanleModal()
                    requestVideoList({ page: 1 })
                })
                .catch((error) => {
                    message.error(error.message)
                })
        })
    }
    React.useEffect(() => {
        if (state.visibleModal) {
            requestProjectList()
        }
    }, [state.visibleModal])
    const handleSearch = (value: string) => {
        setSearchState((preState) => ({ ...preState, filter: value, page: 1 }))
    }
    return (
        <React.Fragment>
            <Row justify="end">
                <Button onClick={handleTurnChanleModal} type="primary">
                    添加
                </Button>
            </Row>
            <Row gutter={[0, 30]}>
                <Col span={6}>
                    <Search
                        placeholder="国标编号，项目名称或安监备案号"
                        onSearch={handleSearch}
                    ></Search>
                </Col>
            </Row>
            <Table
                rowKey={(record: any) => record.id}
                pagination={{
                    hideOnSinglePage: true,
                    total: VideoListState.total,
                    current: VideoListState.page,
                    onChange: (page) => {
                        setSearchState((preState) => ({ ...preState, page }))
                    },
                }}
                columns={videoListColums}
                dataSource={VideoListState.dataSource}
                loading={VideoListState.loading}
            ></Table>
            <Modal
                title="添加设备"
                visible={state.visibleModal}
                okText="确认"
                cancelText="取消"
                onOk={onAdd}
                okButtonProps={{ loading: addState.loading }}
                onCancel={handleTurnChanleModal}
            >
                <Form form={form} labelCol={{ span: 5 }}>
                    <Form.Item
                        name="name"
                        label="设备名"
                        required
                        rules={[{ required: true, message: '请输入设备名' }]}
                    >
                        <Input placeholder="请输入设备名称"></Input>
                    </Form.Item>
                    <Form.Item
                        name="projectId"
                        label="工程名"
                        required
                        rules={[{ required: true, message: '请选择工程项目' }]}
                    >
                        <Select placeholder="请选择工程项目">
                            {projectListState.dataSouce.map((project) => {
                                return (
                                    <Select.Option
                                        key={project.id}
                                        value={project.id}
                                    >
                                        {project.name}
                                    </Select.Option>
                                )
                            })}
                        </Select>
                    </Form.Item>
                    {/* 暂时注释 */}
                    {/* <Form.Item
                        name="vedioType"
                        label="视频类型"
                        required
                        rules={[{ required: true, message: '请选择视频类型' }]}
                    >
                        <Select placeholder="请选择视频类型">
                            <Select.Option value={0}>NVR</Select.Option>
                            <Select.Option value={1}>IPC</Select.Option>
                        </Select>
                    </Form.Item> */}
                </Form>
            </Modal>
        </React.Fragment>
    )
}
export default videos
