import React, { lazy } from 'react'
import {
    DesktopOutlined,
    FileSyncOutlined,
    SettingOutlined,
    DownOutlined,
    LoginOutlined,
} from '@ant-design/icons'
import {
    BrowserRouter as Router,
    Route,
    Switch,
    Redirect,
} from 'react-router-dom'
import LoadingPage from '../components/loadingPage'
import login from '../pages/login'
import AdminLayout from '../layout'
import equipment from '../pages/dust'
import warehousing from '../pages/access'
import disassemble from '../pages/disassemble'
import video from '../pages/videos'
import chanle from '../pages/chanle'
import docking from '../pages/docking'
const regisetrQuery = lazy(() => import('../pages/regisetr-query'))
const forget = lazy(() => import('../pages/forget'))
const register = lazy(() => import('../pages/register'))
const setUp = lazy(() => import('../pages/setup'))

const wrapperLoading = (Component: React.FC<any>) => (props: any) => {
    return (
        <React.Suspense fallback={<LoadingPage />}>
            <Component {...props}></Component>
        </React.Suspense>
    )
}
export const menuConfigs = [
    {
        title: '设备管理',
        key: 'device',
        icon: <DesktopOutlined></DesktopOutlined>,
        childs: [
            {
                title: '扬尘设备',
                key: '/admin/equipment/hadware',
                path: '/admin/equipment/hadware',
            },
            {
                title: '视频监控',
                key: '/admin/equipment/video',
                path: '/admin/equipment/video',
            },
        ],
    },
    {
        title: '申报',
        key: 'apply',
        icon: <FileSyncOutlined></FileSyncOutlined>,

        childs: [
            {
                title: '类型申请',
                key: '/admin/equipment/warehousing',
                path: '/admin/equipment/warehousing',
            },
            {
                title: '对接申请',
                key: '/admin/equipment/docking',
                path: '/admin/equipment/docking',
            },
            {
                title: '拆机申报',
                key: '/admin/equipment/disassemble',
                path: '/admin/equipment/disassemble',
            },
        ],
    },
]

export default () => {
    return (
        <Router>
            <Switch>
                <Route path="/" exact component={login}></Route>

                <Route
                    path="/register"
                    exact
                    component={wrapperLoading(register)}
                ></Route>
                <Route
                    path="/queryUser"
                    exact
                    component={wrapperLoading(regisetrQuery)}
                ></Route>
                <Route
                    path="/forget"
                    exact
                    component={wrapperLoading(forget)}
                ></Route>
                <Route
                    path="/admin"
                    exact
                    render={() => (
                        <Redirect to="/admin/equipment/hadware"></Redirect>
                    )}
                ></Route>
                <Route
                    path="/admin"
                    render={(props) => (
                        <AdminLayout
                            {...props}
                            routes={[
                                {
                                    path: '/admin/equipment/setUp',
                                    component: wrapperLoading(setUp),
                                },
                                {
                                    path: '/admin/equipment/hadware',
                                    component: equipment,
                                },
                                {
                                    path: '/admin/equipment/video',
                                    component: video,
                                },
                                {
                                    path: '/admin/equipment/chanle',
                                    component: chanle,
                                },
                                {
                                    path: '/admin/equipment/warehousing',
                                    component: warehousing,
                                },
                                {
                                    path: '/admin/equipment/docking',
                                    component: docking,
                                },
                                {
                                    path: '/admin/equipment/disassemble',
                                    component: disassemble,
                                },
                            ]}
                        ></AdminLayout>
                    )}
                ></Route>
            </Switch>
        </Router>
    )
}
