import * as React from 'react'
import request from '../utils/request'
export const DeviceTypeDictionary = {
    0: '待审核',
    1: '审核通过',
    2: '审核退回',
}

export type DeviceTypeRecordProps = {
    created_time: string
    status: keyof typeof DeviceTypeDictionary
    type_code: number
    type_name: string
    agent: string
    agent_phone: string
    feedback: string
    appendix: string[]
    approve_time: string
    need_appendix: boolean
}

/**
 * @description 获取设备类型
 */
export const useDeviceTypes = () => {
    const [state, setState] = React.useState<{
        loading: boolean
        dataSource: DeviceTypeRecordProps[]
    }>({
        loading: false,
        dataSource: [],
    })
    /**
     *
     * @param params 0. 已对接的设备类型 1 设备类型申请列表 2 设备类型对接列表 3.可申请的设备类型 4 可对接的设备类型
     */
    const requestTypes = (params: { list_type: 0 | 1 | 2 | 3 | 4 }) => {
        return request
            .sendRequest({
                url: '/v1/device/type_list',
                params,
            })
            .then((data: any) => {
                setState((preState) => ({
                    ...preState,
                    dataSource: data.map((element) => {
                        return {
                            ...element,
                            appendix: element.appendix
                                ? JSON.parse(element.appendix)
                                : [],
                        }
                    }),
                    loading: false,
                }))
            })
            .catch((error) => {
                setState((preState) => ({
                    ...preState,
                    loading: false,
                }))
            })
    }
    return { state, requestTypes } as const
}
/**
 * @description 申请设备类型
 */
export const useAddDeviceType = () => {
    const [state, setState] = React.useState<{
        loading: boolean
    }>({
        loading: false,
    })
    const requestAddType = (data: {
        agent: string
        agent_phone: string
        comment: string
        device_type: number
    }) => {
        setState((preState) => ({ ...preState, loading: true }))
        return request
            .sendRequest({
                url: '/v1/device/type',
                method: 'POST',
                data,
            })
            .finally(() => {
                setState((preState) => ({ ...preState, loading: false }))
            })
    }
    return { state, requestAddType } as const
}
/**
 * @description 设备类型对接申请
 */
export const useApplyDockDeviceTypes = () => {
    const [state, setState] = React.useState<{
        loading: boolean
    }>({
        loading: false,
    })
    const requestApply = (data: {
        agent: string
        agent_phone: string
        comment: string
        appendix: string
        device_type: number
    }) => {
        setState((preState) => ({ ...preState, loading: true }))
        return request
            .sendRequest({
                url: '/v1/device/type_testing',
                method: 'POST',
                data,
            })
            .finally(() => {
                setState((preState) => ({ ...preState, loading: false }))
            })
    }
    return { state, requestApply } as const
}

//设备类型总列表 用于公示页面
export const useDeviceTotalTypes = () => {
    const [state, setState] = React.useState<{
        loading: boolean
        dataSource: { type_code: number; type_name: string }[]
    }>({
        loading: false,
        dataSource: [],
    })
    const requestypes = () => {
        setState((preState) => ({ ...preState, loading: true }))
        request
            .sendRequest({
                url: '/v1/device_type_all',
            })
            .then((data: any) => {
                setState((preState) => ({
                    ...preState,
                    loading: false,
                    ...data,
                    dataSource: data.list,
                }))
            })
            .catch((error) => {})
    }
    return [state, requestypes] as const
}
