import * as React from 'react'
import Request from '../utils/request'

export const DisassembleStatus = {
    0: '待审核',
    1: '审核通过',
    2: '审核被拒',
}
/**
 * @description 拆机列表
 */
export const useDisassembleList = () => {
    const [state, setState] = React.useState({
        loading: false,
        total: 0,
        page: 1,
        dataSource: [],
    })
    const request = (params: { page: number; filter: string }) => {
        setState((preState) => ({
            ...preState,
            loading: true,
        }))
        return Request.sendRequest({
            url: '/v1/device/del_job_list',
            params,
        })
            .then((data: any) => {
                setState((preState) => ({
                    ...preState,
                    loading: false,
                    ...data,
                    dataSource: data.list.map((element: any) => {
                        return {
                            ...element,
                            statusText:
                                DisassembleStatus[element.status as 0 | 1 | 2],
                        }
                    }),
                }))
            })
            .catch((error) => {
                setState((preState) => ({
                    ...preState,
                    loading: false,
                }))
            })
    }
    return [state, request] as const
}
/**
 * @description 提交设备拆机申报
 */
export const usePostDisassemble = () => {
    const [state, setState] = React.useState({
        loading: false,
        dataSource: [],
    })
    const request = (data: { id: string; reason: string }) => {
        setState((preState) => ({ ...preState, loading: true }))
        return Request.sendRequest({
            url: '/v1/device',
            method: 'delete',
            data,
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return [state, request] as const
}
