import * as React from 'react'
import Request from '../utils/request'
export const DeviceStatus = {
    0: '待审核',
    1: '项目通过',
    2: '项目不通过',
}
export const DevicestateKeys = {
    offLine: 0,
    online: 1,
}
export const Devicestate = {
    0: '离线',
    1: '在线',
}
export type DeviceProps = {
    id: number
    //序号
    index: number
    //工程项目
    project_name: string
    //安监备案号
    safety_record_no: string
    //设备类型
    type_name: string
    //密钥
    key: string
    //入库时间
    warehouse_time: string
    //设备状态
    status: keyof typeof DeviceStatus
}
export const test = 1
/**
 * @deprecated 设备列表
 */
export const useDeviceLists = () => {
    const [state, setState] = React.useState<{
        loading: boolean
        dataSource: any[]
        total: number
        page: number
        deepProps: { filter: string; page: number; type_code: '' | number }
    }>({
        loading: false,
        dataSource: [],
        deepProps: {
            page: 1,
            filter: '',
            type_code: '',
        },
        total: 0,
        page: 1,
    })
    const requestList = (parmas: {
        filter: string
        page: number
        type_code: '' | number
    }) => {
        setState((preState) => ({
            ...preState,
            loading: true,
            deepProps: { ...preState.deepProps, ...parmas },
        }))
        Request.sendRequest({
            url: '/v1/device/list',
            params: parmas,
        })
            .then((data: any) => {
                data.list = data.list || []
                setState((preState) => ({
                    ...preState,
                    ...data,
                    loading: false,
                    dataSource: data.list.map((element: any, index: number) => {
                        return { ...element, index: index + 1 }
                    }),
                }))
            })
            .catch((error) => {
                setState((preState) => ({ ...preState, loading: false }))
            })
    }
    return [state, requestList] as const
}
/**
 * 新增设备
 */
export const useInsertDevice = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const requestInsert = (data: {
        project_id: number
        sn: string
        type: number
    }) => {
        setState((preState) => ({ ...preState, loading: true }))

        return Request.sendRequest({
            url: '/v1/device',
            method: 'POST',
            data,
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return [state, requestInsert] as const
}
/**
 * @description 可拆机的设备列表
 */
export const useCanDeleteDeviceList = (options = { auto: true }) => {
    const [state, setState] = React.useState<{
        loading: boolean
        dataSource: { id: string; name: string }[]
    }>({
        loading: false,
        dataSource: [],
    })
    const requestInsert = () => {
        setState((preState) => ({ ...preState, loading: true }))
        return Request.sendRequest({
            url: '/v1/device/can_del_list',
        })
            .then((data: any) => {
                setState((preState) => ({
                    ...preState,
                    ...data,
                    loading: false,
                    dataSource: data.list,
                }))
            })
            .catch((error) => {
                setState((preState) => ({
                    ...preState,
                    loading: false,
                }))
            })
    }
    return [state, requestInsert] as const
}
