import * as React from 'react'
import Request from '../utils/request'
export const DeviceState = {
    0: '离线',
    1: '在线',
}
export const ApplyDustStatus = {
    0: '待确认',
    1: '已确认',
    2: '非本项目',
}
export type ApplyDustFormProps = {
    batch: string
    device_model: string
    manufacturer: string
    name: string
    person: string
    phone: string
    project_id: number
    remark: string
    sn: string
    url: string
}
export type DustRecordProps = {
    apply_time: string
    approve_time: string
    key: string
    id: number
    status: keyof typeof ApplyDustStatus
    state: keyof typeof DeviceState
    statusText: string
    stateText: string
} & ApplyDustFormProps
/**
 * @description 获取扬尘设备列表
 */
export const useDustList = () => {
    const [state, setState] = React.useState<{
        loading: boolean
        dataSource: DustRecordProps[]
        total: number
        page: number
    }>({
        loading: false,
        dataSource: [],
        total: 0,
        page: 1,
    })
    const request = (params: { page: number; filter: string }) => {
        setState((preState) => ({ ...preState, loading: true }))
        return Request.sendRequest({
            url: '/v1/device/dust_list',
            params,
        })
            .then((data: any) => {
                setState((preState) => ({
                    ...preState,
                    ...data,
                    loading: false,
                    dataSource: data.list?.map((element: DustRecordProps) => {
                        return {
                            ...element,
                            statusText: ApplyDustStatus[element.status],
                            stateText: DeviceState[element.state],
                        }
                    }),
                }))
            })
            .catch((error) => {
                setState((preState) => ({
                    ...preState,
                    loading: false,
                }))
            })
    }
    return { state, request } as const
}
/**
 * @description 新增设备
 */
export const useInsertDevice = () => {
    const [state, setState] = React.useState<{
        loading: boolean
        dataSource: any[]
        total: number
        page: number
    }>({
        loading: false,
        dataSource: [],
        total: 0,
        page: 1,
    })
    const request = (data: ApplyDustFormProps) => {
        setState((preState) => ({ ...preState, loading: true }))
        return Request.sendRequest({
            url: '/v1/device/dust',
            data,
            method: 'POST',
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return { state, request } as const
}
