import * as React from 'react'
import Resuest from '../utils/request'
export const useUserLogin = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const request = (data: {
        user: string
        password: string
        verify: string
    }) => {
        setState((preState) => ({ ...preState, loading: true }))
        return Resuest.sendRequest({
            url: '/v1/user/login',
            method: 'POST',
            data,
        })
            .then((data: any) => {
                localStorage.setItem('token', data.token)
                localStorage.setItem('refresh_token', data.refresh_token)

                return data
            })
            .finally(() => {
                setState((preState) => ({ ...preState, loading: false }))
            })
    }
    return [state, request] as const
}
/**
 * @description 获取图片验证码ID
 */
export const useCaptchaId = () => {
    const [state, setState] = React.useState({
        loading: false,
        data: {
            capture_id: '',
        },
    })
    const request = () => {
        setState((preState) => ({ ...preState, loading: true }))
        return new Promise((resolve, reject) => {
            Resuest.sendRequest({
                url: '/v1/user/captcha_id',
            })
                .then((data: any) => {
                    setState((preState) => ({ ...preState, data }))
                    resolve(data)
                })
                .catch((error) => {
                    reject(error)
                })
                .finally(() => {
                    setState((preState) => ({ ...preState, loading: false }))
                })
        })
    }
    return [state, request] as const
}
export const useSendCode = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const request = async (params: { phone: string }) => {
        setState((preState) => ({ ...preState, loading: true }))
        await Resuest.sendRequest({
            url: '/v1/vcode',
            params,
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return { state, request } as const
}
export const useChangePassWord = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const request = async (data: {
        passwd: string
        phone: string
        vcode: number
    }) => {
        setState((preState) => ({ ...preState, loading: true }))
        await Resuest.sendRequest({
            url: '/v1/user/set_passwd',
            method: 'PUT',
            data,
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return { state, request } as const
}
export const useQueryUser = () => {
    const [state, setState] = React.useState<{
        loading: boolean
        data?: {
            status: number
            feedback: string
            approve_time: string
        }
    }>({
        loading: false,
    })
    const request = async (params: { social_code: string }) => {
        setState((preState) => ({ ...preState, loading: true }))
        await Resuest.sendRequest({
            url: '/v1/user/status',
            params,
        })
            .then((data: any) => {
                setState((preState) => ({ ...preState, loading: false, data }))
            })
            .finally(() => {
                setState((preState) => ({ ...preState, loading: false }))
            })
    }
    return { state, request } as const
}
/**
 * @description 修改邮箱
 */
export const useChangeEmail = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const request = (data: { email: string; password: string }) => {
        return Resuest.sendRequest({
            url: '/v1/user/verify_mail',
            method: 'PUT',
            data,
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return { state, request } as const
}
/**
 * @description 发送验证码
 */
export const useSendPhoneCode = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const request = (params: { phone: string }) => {
        return Resuest.sendRequest({
            url: '/v1/vcode',
            params,
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return { state, request } as const
}
/**
 * @description 修改手机号
 */
export const useChangePhone = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const request = (data: { phone: string; vcode: number }) => {
        return Resuest.sendRequest({
            url: '/v1/user/phone',
            method: 'PUT',
            data,
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return { state, request } as const
}
/**
 * @description 获取用户信息
 */
export const useGetUrerInfo = () => {
    const [state, setState] = React.useState({
        loading: false,
        data: { email: '', phone: '', code: '' },
        error: null,
    })
    const request = () => {
        setState((preState) => ({ ...preState, loading: true }))
        Resuest.sendRequest({
            url: '/v1/user/info',
        })
            .then((data: any) => {
                setState((preState) => ({ ...preState, loading: false, data }))
            })
            .catch((error) => {
                setState((preState) => ({ ...preState, loading: false, error }))
            })
    }
    return { state, request } as const
}
/**
 * @description 重置用户密码
 */
export const useChangePassword = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const request = (data: { new: string; old: string }) => {
        setState((preState) => ({ ...preState, loading: true }))
        return Resuest.sendRequest({
            url: '/v1/user/change_passwd',
            data,
            method: 'PUT',
        })
            .then((data: any) => {
                setState((preState) => ({ ...preState, loading: false, data }))
            })
            .catch((error) => {
                setState((preState) => ({ ...preState, loading: false, error }))
            })
    }
    return { state, request } as const
}
