import * as React from 'react'
import Resuest from '../utils/request'

export const VideoStatus = {
    0: '待确认',
    1: '已确认',
    2: '非本项目',
}
export const VideoState = {
    0: '离线',
    1: '在线',
}
export const chanleState = {
    0: '离线',
    1: '在线',
}

/**
 * @description 获取视频设备列表
 */
export const useVideoList = () => {
    const [state, setState] = React.useState({
        loading: false,
        dataSource: [],
        total: 0,
        page: 1,
    })
    const request = (params: { page: number; filter?: string }) => {
        setState((preState) => ({ ...preState, loading: true }))
        return Resuest.sendRequest({
            url: '/v1/device/vedio_list',
            params,
        })
            .then((data: any) => {
                setState((preState) => ({
                    ...preState,
                    ...data,
                    loading: false,
                    dataSource: data.list,
                }))
            })
            .catch((error) => {
                setState((preState) => ({ ...preState, loading: false }))
            })
    }

    return [state, request] as const
}
/**
 * @description 获取视频通道列表
 * @param options
 */
export const useVideoChanel = () => {
    const [state, setState] = React.useState({
        loading: false,
        dataSource: [],
        deepProps: {
            page: 1,
            sn: '',
            channel_no: '',
        },
        total: 0,
        page: 1,
    })
    const request = (params: {
        sn?: string
        page?: number
        channel_no?: string
    }) => {
        setState((preState) => ({
            ...preState,
            loading: true,
            deepProps: { ...preState.deepProps, ...params },
        }))
        return Resuest.sendRequest({
            url: '/v1/device/vedio_channel_list',
            params,
        })
            .then((data: any) => {
                setState((preState) => ({
                    ...preState,
                    loading: false,
                    dataSource: data.list,
                    total: data.total,
                    page: data.page,
                }))
            })
            .catch((error) => {
                setState((preState) => ({ ...preState, loading: false }))
            })
    }
    return [state, request] as const
}
/**
 * @description 添加视频通道
 */
export const useAddChanle = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const request = (data: { channelCount: number; sn: string }) => {
        setState((preState) => ({ ...preState, loading: true }))
        return Resuest.sendRequest({
            url: '/v1/device/vedio_channel',
            method: 'POST',
            data,
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return [state, request] as const
}

/**
 * @description 添加视频
 */
export const useAddVideo = () => {
    const [state, setState] = React.useState({
        loading: false,
    })
    const request = (data: {
        name: string
        projectId: number
        // vedioType: number
    }) => {
        setState((preState) => ({ ...preState, loading: true }))
        return Resuest.sendRequest({
            url: '/v1/device/vedio',
            method: 'POST',
            data,
        }).finally(() => {
            setState((preState) => ({ ...preState, loading: false }))
        })
    }
    return [state, request] as const
}
