import Axios, { AxiosRequestConfig } from 'axios'
const prefix = '/api'
const refreshTokenCodes = 10009
const logOutCode = 10010

const instance = Axios.create({
    baseURL: prefix,
})
/**
 * @description 刷新token
 */
const refreshToken = () => {
    return instance({
        url: '/v1/token_refresh',
        method: 'PUT',
        headers: {
            token: localStorage.getItem('refresh_token'),
        },
    }).then((data: any) => {
        localStorage.setItem('token', data)
        return data
    })
}
let isRefreshing = false
let cacheRequests: any[] = []
// 请求拦截
instance.interceptors.request.use((requestConfig) => {
    return {
        ...requestConfig,
        params: {
            ...requestConfig.params,
            random:
                requestConfig.method === 'GET' || requestConfig.method === 'get'
                    ? Math.random()
                    : '',
        },
        headers: {
            token: localStorage.getItem('token'),
            ...requestConfig.headers,
        },
    }
})
/**
 * @description 拦截响应
 */
instance.interceptors.response.use(
    (response) => {
        if (response.data.code === refreshTokenCodes) {
            if (!isRefreshing) {
                isRefreshing = true
                return refreshToken()
                    .then((data) => {
                        localStorage.setItem('token', data)
                        cacheRequests.forEach((cb) => cb(data))
                        cacheRequests = []
                        return instance({
                            ...response.config,
                            headers: {
                                ...response.config.headers,
                                token: data,
                            },
                        })
                    })
                    .finally(() => {
                        isRefreshing = false
                    })
            } else {
                return new Promise((resolve) => {
                    cacheRequests.push((token: string) => {
                        resolve(
                            instance({
                                ...response.config,
                                headers: {
                                    ...response.config.headers,
                                    token: token,
                                },
                            })
                        )
                    })
                })
            }
        }
        if (response.data.code === logOutCode) {
            localStorage.clear()
            window.location.href = '/'
            return Promise.reject(response.data)
        }

        if (response.data.code === 0) {
            return Promise.resolve(response.data.data)
        } else {
            return Promise.reject(response.data)
        }
    },
    (error) => Promise.reject(error)
)
export default {
    sendRequest: (config: AxiosRequestConfig) => {
        return instance(config)
    },
}
